==> typebuild-0.0.23.tar.gz: typebuild-0.0.23/setup.py <==
from glob import glob
from setuptools import setup, find_packages
import os
# Read requirements from requirements.txt
with open('requirements.txt') as f:
    requirements = f.read().splitlines()

# Read the contents of your README file
with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

# Get the path to the images directory
images_dir = os.path.join(os.path.dirname(__file__), 'typebuild', 'images')
# Get a list of all files in the images directory with any extension
images_list = glob(os.path.join(images_dir, '*.*'))

setup(
    name="typebuild",
    version="0.0.23",
    packages=find_packages(),
    include_package_data=True,
    package_data={
        'typebuild': images_list,
    },
    install_requires=requirements,
    author="iRanadheer",
    author_email="neneranadheer@gmail.com",
    description="A brief description of your package",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/project-typebuild/typebuild",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: Other/Proprietary License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10"       

    ],
    entry_points={
        'console_scripts': [
            'typebuild = typebuild.app:run',
        ],
    },
)

==> typebuild-0.0.25.tar.gz: typebuild-0.0.25/setup.py <==
from glob import glob
from setuptools import setup, find_packages
import os
# Read requirements from requirements.txt
with open('requirements.txt') as f:
    requirements = f.read().splitlines()

# Read the contents of your README file
with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

# Get the path to the images directory
images_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'images')

# Get a list of all files in the images directory with any extension
images_list = glob(os.path.join(images_dir, '*.*'))

setup(
    name="typebuild",
    version="0.0.25",
    packages=find_packages(),
    include_package_data=True,
    package_data={
        'typebuild': images_list,
    },
    install_requires=requirements,
    author="iRanadheer",
    author_email="neneranadheer@gmail.com",
    description="A brief description of your package",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/project-typebuild/typebuild",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: Other/Proprietary License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10"       

    ],
    entry_points={
        'console_scripts': [
            'typebuild = typebuild.app:run',
        ],
    },
)
